====
dwai
====


.. image:: https://img.shields.io/pypi/v/dwai.svg
        :target: https://pypi.python.org/pypi/dwai

.. image:: https://img.shields.io/travis/tluo-github/dwai.svg
        :target: https://travis-ci.com/tluo-github/dwai

.. image:: https://readthedocs.org/projects/dwai/badge/?version=latest
        :target: https://dwai.readthedocs.io/en/latest/?version=latest
        :alt: Documentation Status




云商大模型Python SDK


* Free software: Apache Software License 2.0
* Documentation: https://dwai.readthedocs.io.


Features
--------

* 支持微软、千问、腾讯、华为 大语言模型推理调用
